@@ -18,7 +18,6 @@ download and a section ``projects:`` that contains a list of projects to fetch.
            dst: external/mymodule/
 """
 import io
-import logging
 import os
 from typing import IO, Any, Dict, List, Sequence, Tuple, Union
 
@@ -26,11 +25,13 @@ import yaml
 from typing_extensions import TypedDict
 
 import dfetch.manifest.validate
+from dfetch import DEFAULT_MANIFEST_NAME
+from dfetch.log import get_logger
 from dfetch.manifest.project import ProjectEntry, ProjectEntryDict
 from dfetch.manifest.remote import Remote, RemoteDict
 from dfetch.util.util import find_file
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class ManifestDict(TypedDict):
@@ -180,7 +181,7 @@ class Manifest:
 
 def find_manifest() -> str:
     """Find a manifest."""
-    paths = find_file("manifest.yaml", ".")
+    paths = find_file(DEFAULT_MANIFEST_NAME, ".")
 
     if len(paths) == 0:
         raise RuntimeError("No manifests were found!")
