@@ -1,6 +1,4 @@
 """All Project related items."""
-import logging
-
 import dfetch.manifest.project
 from dfetch.project.git import GitRepo
 from dfetch.project.svn import SvnRepo
@@ -9,12 +7,14 @@ from dfetch.project.vcs import VCS
 SUPPORTED_PROJECT_TYPES = [GitRepo, SvnRepo]
 
 
-def make(
-    project_entry: dfetch.manifest.project.ProjectEntry, logger: logging.Logger
-) -> VCS:
+def make(project_entry: dfetch.manifest.project.ProjectEntry) -> VCS:
     """Create a new VCS based on a project from the manifest."""
     for project_type in SUPPORTED_PROJECT_TYPES:
-        project = project_type(project_entry, logger)
+        if project_type.NAME == project_entry.vcs:
+            return project_type(project_entry)
+
+    for project_type in SUPPORTED_PROJECT_TYPES:
+        project = project_type(project_entry)
 
         if project.check():
             return project
